function [Av , Bv , Cv ]=dist2dsmfun(phat,h2,CSMA,lin_extrap)
%DIST2DSMFUN Smooths the conditional DIST2D distribution parameters. 
%
% CALL:  [A, B, C] = dist2dsmfun(phat,x2,csm,lin)
%
%   A, B, C = scale shape and location parameter, respectively
%             evaluated at x2
%   phat    = parameter structure array (see dist2dfit)
%   x2      = evaluation points (default phat.x{1}(:,1)) 
%   csm     = [csma csmb csmc], smoothing parameter vector which defines
%             the smoothing of parameter A,B and C, respectively 
%             0 -> LS straight line
%             1 -> cubic spline interpolant (default [1 1 1])
%   lin     = [lina linb linc], vector defining the extrapolation of
%             the parameters A,B and C,  respectively (default [1 1 1])
%             0 No linear extrapolation outside the range of data
%             1 Linear extrapolation outside the range of data 
%
%   The size of A B and C is the size of the argument  X2.
%   
% See also:  dist2dfit, dist2dsmfun2, smooth


% Tested on matlab 5.x
% history
% revised pab 03.12.2000
% - added truncated weibull and truncated rayleigh
% revised pab 12.11.2000
%  - added wggampdf option
%  Per A. Brodtkorb 28.10.98

PVH=phat.x{1};
ind=find(~isnan(PVH(:,1)));
PVH=PVH(ind,:);
CDIST=phat.dist{1};  
if nargin<2 |isempty(h2),
  h2=PVH(:,1);
end

CSMB=1;
CSMC=1;
if nargin<3|isempty(CSMA)
  CSMA = 1;
elseif length(CSMA)==2
  CSMB=CSMA(2);
  CSMA=CSMA(1);
elseif length(CSMA)>=2
  CSMB=CSMA(2);
  CSMC=CSMA(3);
  CSMA=CSMA(1);
end
linB=1;
linC=1;
if (nargin<4) | isempty(lin_extrap),
    linA=1;
elseif length(lin_extrap)==2,
  linA=lin_extrap(1);
  linB=lin_extrap(2);
elseif length(lin_extrap)>=2,
  linA=lin_extrap(1);
  linB=lin_extrap(2);
  linC=lin_extrap(3);
end
%smooth extrapolates linearly outside the range of PVH
useSIG=0; % 
if useSIG & isfield(phat,'CI') 
  da=(diff(phat.CI{1}(ind,1:2),1,2)/4).^2; % approximate 2 standard deviations
else
  da=ones(size(PVH(:,1)));
end
Av=smooth(PVH(:,1),PVH(:,2),CSMA,h2,linA,da);
switch lower(CDIST(1:2)),
  case {'ra','tr','tg','gu','ga','we','tw','gg'}, 
    if (any(Av<0)),
      Av=exp(smooth(PVH(:,1),log(PVH(:,2)),CSMA,h2,linA));
    end
end
Bv=[];	  
if ~strcmp(lower(CDIST(1:2)),'ra')
  if useSIG & isfield(phat,'CI') 
    db=(diff(phat.CI{1}(ind,3:4),1,2)/4).^2; % approximate 2 standard deviations
  else
    db=ones(size(PVH(:,1)));
  end
  Bv=smooth(PVH(:,1),PVH(:,3),CSMB,h2,linB,db);
  switch CDIST(1:2) ,
    case {'lo','ga','we','tw','gg'},  
      if  (any(Bv<0)),
	Bv=exp(smooth(PVH(:,1),log(PVH(:,3)),CSMB,h2,linB));
      end
  end 
end
Cv=0;
if (((size(PVH,2)>=4) & (~strcmpi(CDIST(1:2),'ra'))) | ((size(PVH,2)>=3) & (strcmpi(CDIST(1:2),'ra')))),
  Cv=smooth(PVH(:,1),PVH(:,4),CSMC,h2,linC);
  switch lower(CDIST(1:2)) ,
    case {'ra','tg','lo','ga','we'},  
      if  (any(Cv<0)),
	Cv(Cv<0)=0;
      end
    case 'gg',
       if  (any(Cv<0)),
	Cv=exp(smooth(PVH(:,1),log(PVH(:,4)),CSMC,h2,linC));
      end 
  end 
end
return


