function sphat=dist2dsmfun2(phat,h2,csm,lin,visual)
%DIST2DSMFUN2 Smooths the conditional DIST2D distribution parameters. 
% 
% CALL:  sphat = dist2dgsmfun2(phat,x2,csm,lin)
% 
%    sphat = smoothed parameter structure array evaluated at x2
%    phat  = parameter structure array
%    x2    = evaluation points (default phat.x{1}(:,1)) 
%    csm   = [csma csmb csmc], smoothing parameter vector which defines
%            the smoothing of parameter A,B and C, respectively 
%            0 -> LS straight line
%            1 -> cubic spline interpolant (default [1 1 1])
%    lin   = [lina linb linc], vector defining the extrapolation of
%            the parameters A,B and C,  respectively (default [1 1 1])
%            0 : No linear extrapolation outside the range of data
%            1 : Linear extrapolation outside the range of data 
%  visual  = 0 : No visual fitting by the user (default)
%            1 : Visual fitting by the user by specifying points using
%                the mouse and interpolate the points with a spline afterwards.
%
%  See also:  dist2dfit smooth 

% Tested on: Matlab 5.2
% history
% revised pab 08.02.2000
%  - added visual
% by  Per A. Brodtkorb 28.10.98


if nargin<2 |isempty(h2),
  h2=phat.x{1}(:,1);
end
h2=h2(:);

if nargin<3|isempty(csm)
  csm= [];
end
if (nargin<4) | isempty(lin),
    lin=[];
end
if (nargin<5) | isempty(visual),
    visual=0;
end
sphat=phat;

if isfield(phat,'CI')
  sphat=rmfield(sphat,'CI');
end
sphat.date=datestr(now);
pvhsiz=size(phat.x{1});
 
n=length(h2(:));
spvhsiz=[n pvhsiz(2)];
sphat.x{1}=zeros(spvhsiz);
sphat.x{1}(:,1)=h2;

[sphat.x{1}(:,2), Bv , Cv]=dist2dsmfun(phat,h2,csm,lin);


if ~isempty(Bv)
  sphat.x{1}(:,3)=Bv;  
end

if ~isempty(Cv) & any(Cv~=0),
  sphat.x{1}(:,4)=Cv;
  
end
sphat.csm=csm;
sphat.lin=lin;

if ~visual, return, end

% Visual Fitting of the parameters starts here:
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

% this may be as good as any other method when extrapolating the
% parameter outside the observed range.

clf
dist2dparamplot(phat,sphat,1)
[x,y]=graphicinput;
sphat.visual=~isempty(x);
if ~isempty(x),
  sphat.x{1}(:,2)=smooth(x,y,1,sphat.x{1}(:,1),1);
  hold on, plot(h2,sphat.x{1}(:,2),'g-'),hold off % plot visual fit
end

if ~isempty(Bv)
  figure(gcf+1)
  dist2dparamplot(phat,sphat,2)
  [x,y]=graphicinput;
  sphat.visual(2)=~isempty(x);
  if ~isempty(x),
    sphat.x{1}(:,3)=smooth(x,y,1,sphat.x{1}(:,1),1);
    hold on, plot(h2,sphat.x{1}(:,3),'g-'),hold off % plot visual fit
  end
end
if ~isempty(Cv) & any(Cv~=0),
  if strcmpi(phat.dist{1}(1:2),'ra'), col=2;else,col=3;end
  figure(gcf+1)
  dist2dparamplot(phat,sphat,col)
  [x,y]=graphicinput;
  sphat.visual(col)=~isempty(x);
  if ~isempty(x),
    sphat.x{1}(:,col+1)=smooth(x,y,1,sphat.x{1}(:,1),1);
    hold on, plot(h2,sphat.x{1}(:,2),'g-'),hold off % plot visual fit
  end 
end

return



function [x, y]= graphicinput,
% Local function which reads points selected with the mouse from screen
% 
  x=[];y=[];
  n=0;
  lim=axis; % find the current scaling of the figure
  %answer = input(['Enter scaling for the current plot. (default [' num2str(lim,4) '] )'])
  prompt={'Enter scaling for the current plot.'};
  answer=inputdlg(prompt,'Visual fitting',1,{ num2str(lim,4) },'on');	
  Na=length(answer);
  if Na>0,
    answer{1}=str2num(answer{1});
    if (isempty(answer{1})|all(answer{1}==lim)),  else, axis(answer{1}), end
  end
  
  disp('Left mouse button picks points')
  disp('Right mouse button picks last point')
  disp('(if less than 6 points are selected then no fitting is made.)')
  but=1;
  hold on
  while but==1,
    [xi,yi,but]=ginput(1);
    plot(xi,yi,'go')
    n=n+1;
    x(n,1)=xi;
    y(n,1)=yi;
  end
  if n<6,
    x=[];y=[];
  end
  hold off

