function [r1, r2, ind]= weib2drnd(parm,m,n,tol)
%WEIB2DRND Random numbers from the 2D Weibull distribution.
%
% CALL:  [R1 R2] = weib2drnd(param,M,N,tol);
%
%  R1,R2 = two matrices of simulated data of size M x N
%  param = [A1,B1,A2,B2,C12] parameters of the distribution
%  m, n  = size of R1, R2 (default m=1,n=1)
%  tol   = relative tolerance (default 1e-3)
%
%  The samples are generated by inversion.
%
% Example:
%   [R1 R2]=weib2drnd([2,2,1,3,.8],2000,1);
%   wweibplot(R1);
%   plot(R1,R2,'.')
%
% See also: weib2dcinv, wweibrnd, rand

%tested on matlab 5.1
%history:
% by Per A. Brodtkorb 19.11.98

error(nargchk(1,4,nargin))
if prod(size(parm))~=5,  error('param must have 5 entries.'); end
if nargin<2|isempty(m),m=1;end
if nargin<3|isempty(n),n=1;end
if nargin<4|isempty(tol),tol=1e-3;end

% Return NaN if  ai or b is not positive  
if any(any(parm(1:4) <= 0))| abs(parm(5))>=1;;
  tmp = NaN;
  r2 = tmp(ones(m,n));  
  r1=r2;
  disp('Warning: parameters are not valid, NaNs returned')
  return
end

r1 = zeros(m,n);
r2= r1;

r1=wweibrnd(parm(1),parm(2),m,n);
% perform a direct inversion by newton
P=rand(m,n);
[r2 ind]=weib2dcinv(r1 ,P,parm,tol); % Inverse of the 2D weibull cdf given X1 . slow




