function R = wexprnd(m0,varargin);
%WEXPRND Random matrices from an Exponential distribution
% 
% CALL:  R = wexprnd(m0,sz)
%     
%        R = matrix of random numbers
%       m0 = mean of the Exponential distribution, m0>0
%       sz = size(R)    (Default size(m0))
%            sz can be a comma separated list or a vector 
%            giving the size of R (see zeros for options).
%
% The random numbers are generated by the inverse method. 
%
% Example:
%   R=wexprnd(5,1,100);
%   phat=wweibplot(R)     % Exp is Weibull with c=1
%
% See also: wexpinv, wweibcdf, wweibplot

% Reference: Johnson, Kotz and Balakrishnan (1994)
% "Continuous Univariate Distributions, vol. 1", p. 494 ff
% Wiley

% Tested on: Matlab 5.3
% History: 
% revised pab 24.10.2000
%  - added comnsize, nargchk
%  - made sizing of R more flexible
% added ms 10.08.2000

error(nargchk(1,inf,nargin))
if nargin>1,
 [errorcode m0]=comnsize(m0,zeros(varargin{:}));
 if errorcode
   error('m0 must be a scalar or comply to the size info given.');
 end
end

R = wexpinv(rand(size(m0)),m0);

