function R = wfrnd(a,b,varargin)
%WFRND Random matrices from the Snedecor's F distribution
%
% CALL:  R = wfrnd(df1,df2,sz);
%
%        R = matrix of random numbers
% df1,df2, = degrees of freedom
%       sz = size(R)    (Default size(b))
%            sz can be a comma separated list or a vector 
%            giving the size of R (see zeros for options)
%
% The random numbers are generated by the inverse method. 
% 
% Example:
%   R=wfrnd(1,1,100,1);
%   plot(R,'.')
  
% tested on matlab 5.3
%History:
%revised pab 29.10.2000
% adapted from stixbox
% -added nargchk, comnsize + check that df1, df2 are positive integers
%        Anders Holtsberg, 18-11-93
%        Copyright (c) Anders Holtsberg

error(nargchk(2,inf,nargin))
if nargin<3,
  [errorcode a b] = comnsize(a,b);
else
  [errorcode a b] = comnsize(a,b,zeros(varargin{:}));
end 
if errorcode > 0
  error('df1 and df2 must be a scalar or of corresponding size as given by m and n.');
end


R = zeros(size(a));

ok = (a>0 & b>0 & floor(a)==a & floor(b)==b);

k = find( ok);
if any(k)
  x = wbetarnd(a(k)/2,b(k)/2);
  R(k) = x.*b(k)./((1-x).*a(k));
end


k3=find(~ok);
if any(k3)
  tmp=NaN;
  x(k3)=tmp(ones(size(k3)));
end
