function x = wnorminv(F,m,v)
%WNORMINV Inverse of the Normal distribution function
%
% CALL:  x = wnorminv(F,m,v)
%
%        x = inverse cdf for the Normal distribution evaluated at F
%        m = mean     (default 0)
%        v = variance (default 1)
%
% Example:
%   F = linspace(0,1,100);
%   x = wnorminv(F,2.5,0.6);
%   plot(F,x)
% 
% See also: wnormcdf, wnormpdf, wnormrnd
  
% Tested on: Matlab 6.0, 5.3
% History: 
% revised jr 03.04.2001
%  - fixed a bug in the last if statement
%  - updated information, example
% revised pab 24.10.2000
%  - added comnsize, nargchk
%  - added default values
% added ms 17.06.2000

error(nargchk(1,3,nargin))
if nargin<2|isempty(m),  m=0;  end
if nargin<3|isempty(v),  v=1;  end

[errorcode, F, m, v] = comnsize (F,m, v);
if (errorcode > 0)
  error ('F, m and v must be of common size or scalar');
end

x=zeros(size(F));

ok = ((v>0)&(F>=0)&(F<=1));
k = find (ok);
if any(k)   
  x(k)=sqrt(2*v(k)).*erfinv(2 * F(k) - 1) + m(k);
end

k1 = find (~ok);
if any(k1)
  tmp=NaN;
  x(k1) = tmp(ones(size(k1)));
end



